/*------------- Telecommunications & Signal Processing Lab -------------
                           McGill University

Routine:
  void SAoptions (int argc, const char *argv[], const char **AudioDev,
                  char Ports[3], float *Vol, float *Balance, int *Mute)

Purpose:
  Decode options for SunAudioPort

Description:
  This routine decodes options for SunAudioPort.

Parameters:
   -> int argc
      Number of command line arguments
   -> const char *argv[]
      Array of pointers to argument strings
  <-  char **AudioDev
      Audio device name
  <-  struct AD_DevOpt *DevOpt
      Audio device playback options

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.12 $  $Date: 1999/06/14 16:25:56 $

----------------------------------------------------------------------*/

static char rcsid[] = "$Id: SAoptions.c 1.12 1999/06/14 AFsp-v5r0 $";

#include <libtsp.h>
#include <AD.h>
#include <AO.h>
#include "SunAudioPort.h"

#define ERRSTOP(text,par)	UThalt ("%s: %s: \"%s\"", PROGRAM, text, par)

/* Option table */
static const char *OptTable[] = {
  "-d#", "--d*evice=",
  NULL
};


void
SAoptions (int argc, const char *argv[],const char **AudioDev,
	   struct AD_DevOpt *DevOpt)

{
  const char *OptArg;
  int n;

/* Output port defaults */
  DevOpt_INIT (DevOpt);

  *AudioDev = "";

/* Initialization */
  UTsetProg (PROGRAM);

/* Decode options */
  AOinitOpt (argc, argv);
  while (1) {

    /* Decode audio port options */
    n = ADdecDevOpt (DevOpt);
    if (n >= 1)
      continue;

    /* Decode help options */
    n = AOdecHelp (VERSION, SAMF_Usage);
    if (n >= 1)
      continue;

    /* Decode program options */
    n = AOdecOpt (OptTable, &OptArg);
    if (n == -1)
      break;

    switch (n) {
    case 1:
    case 2:
      /* Audio device */
      *AudioDev = OptArg;
      break;
    default:
      UThalt (SAMF_Usage, PROGRAM);
      break;
    }
  }

  return;
}
