/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  int ADopenControl (const char AudDev[], int Flags)

Purpose:
  Open a Sun audio device for control

Description:
  This routine opens or closes an audio device.  The open function opens an
  audio device for control.

Parameters:
  <-  int ADopenControl
      File descriptor for the audio device
   -> const char AudDev[]
      String containing the audio device name or the name of an environment
      variable (with a leading $)
   -> int Flags
      Control variable
       2 - Print flag.  Print the device name.

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.12 $  $Date: 1999/06/14 16:13:51 $

-------------------------------------------------------------------------*/

static char rcsid[] = "$Id: ADopenControl.c 1.12 1999/06/14 AFsp-v5r0 $";

#include <stdlib.h>		/* getenv prototype */
#include <fcntl.h>		/* open */
#include <string.h>
#include <stropts.h>		/* stream ioctl commands */
#include <unistd.h>		/* ioctl prototype (Solaris) */

#include <libtsp.h>
#include <AD.h>

#define FSET(flag,mask)		(((flag) & (mask)) != 0)
#define PGM			(UTgetProg ())


int
ADopenControl (const char AudioDev[], int Flags)

{
  const char *audiodev;
  int iost;
  int audio_fd;
  int nc;
  char ADevName[FILENAME_MAX];

#ifdef SOLARIS
  audio_device_t AD;
#else
  int AD;
#endif

/* Check for an environment variable */
  if (AudioDev[0] == '$') {
    audiodev = getenv (&AudioDev[1]);
    if (audiodev == NULL)
      audiodev = AUDIO_DEV_DEFAULT;
  }
  else
    audiodev = AudioDev;

/* Form the control device name */
  nc = STcopyMax (audiodev, ADevName, FILENAME_MAX-1);
  if (nc < 3 || strcmp (&ADevName[nc-3], "ctl") != 0) {
    STcatMax ("ctl", ADevName, FILENAME_MAX-1);
    audiodev = ADevName;
  }

/* Open the audio device */
  audio_fd = open (audiodev, O_WRONLY);
  if (audio_fd < 0)
    UTerror ("%s: %s \"%s\"", PGM, ADM_OpenErr, audiodev);

/* Get the device type */
  if (FSET (Flags, AD_PRINT_FLAG)) {
    iost = ioctl (audio_fd, AUDIO_GETDEV, &AD);
    if (iost == -1)
      UTerror ("%s: %s", PGM, ADM_GetErr);

#ifdef SOLARIS
    printf (ADMF_ADev, audiodev, MAX_AUDIO_DEV_LEN, AD.name);
#else
    if (AD < 0)
      AD = 0;
    if (AD >= NAD_type)
      AD = NAD_type - 1;
    printf (ADMF_ADevS, audiodev, AD_type[AD]);
#endif
  }

  return audio_fd;
}
