/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  int AFrdI3 (AFILE *AFp, float Fbuff[], int Nreq)

Purpose:
  Read 24-bit integer data from an audio file (return float values)

Description:
  This routine reads a specified number of 24-bit integer samples from an audio
  file.  The data in the file is converted to float format on output.

Parameters:
  <-  int AFrdI3
      Number of data values transferred from the file.  On reaching the end of
      the file, this value may be less than Nreq.
   -> AFILE *AFp
      Audio file pointer for an audio file opened by AFopenRead
  <-  float Fbuff[]
      Array of floats to receive the samples
   -> int Nreq
      Number of samples requested.  Nreq may be zero.

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.6 $  $Date: 1999/06/11 22:31:32 $

-------------------------------------------------------------------------*/

static char rcsid [] = "$Id: AFrdI3.c 1.6 1999/06/11 AFsp-v5r0 $";

#include <libtsp/nucleus.h>
#include <libtsp/AFdataio.h>
#include <libtsp/AFpar.h>
#include <libtsp/UTtypes.h>

#define LW		FDL_INT24
#define MINV(a, b)	(((a) < (b)) ? (a) : (b))
#define NBBUF		8192

#define FREAD(buf,size,nv,fp)	(int) fread ((char *) buf, (size_t) size, \
					     (size_t) nv, fp)


int
AFrdI3 (AFILE *AFp, float Fbuff[], int Nreq)

{
  int is, N, i, Nr, Hbo;
  int4_t Iv;
  unsigned char Buf[NBBUF];
  unsigned char *cp;
  unsigned char t;
  float g;

  Hbo = UTbyteOrder ();
  cp = (unsigned char *) &Iv;
  for (is = 0; is < Nreq; ) {

    /* Read data from the audio file */
    N = MINV (NBBUF/LW, Nreq - is);
    Nr = FREAD (Buf, LW, N, AFp->fp);

    /* Byte swap and convert to float */
    g = (float) AFp->ScaleF;
    for (i = 0; i < LW*Nr; i += LW) {
      if (AFp->Swapb == DS_SWAP) {
	t = Buf[i+2]; Buf[i+2] = Buf[i]; Buf[i] = t;
      }
      if (Hbo == DS_EL) {
	cp[0] = 0;
	cp[1] = Buf[i];
	cp[2] = Buf[i+1];
	cp[3] = Buf[i+2];	/* Most significant byte */
      }
      else {
	cp[0] = Buf[i];		/* Most significant byte */
	cp[1] = Buf[i+1];
	cp[2] = Buf[i+2];
	cp[3] = 0;
      }
      Fbuff[is] = g * (Iv / 256);
      ++is;
    }

    if (Nr < N)
      break;
  }

  return is;
}
