/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  AFILE *AFsetNHwrite (FILE *fp, int Dformat, int Swapb, long int Nchan,
                       double Sfreq)

Purpose:
  Set file format information for a headerless audio file

Description:
  This routine opens and sets the file format information for a headerless
  audio file.

Parameters:
  <-  AFILE AFsetNHwrite
      Audio file pointer for the audio file.  In case of error, the audio file
      pointer is set to NULL.
   -> FILE *fp
      File pointer for the audio file
   -> int Dformat
      Data format: FD_MULAW8, FD_ALAW8, FD_UINT8, FD_INT8, etc.
   -> int Swapb
      Swap code: DS_EB, DS_EL, DS_NATIVE, or DS_SWAP
   -> long int Nchan
      Number of channels
   -> double Sfreq
      Sampling frequency

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.27 $  $Date: 1999/06/04 20:07:54 $

-------------------------------------------------------------------------*/

static char rcsid [] = "$Id: AFsetNHwrite.c 1.27 1999/06/04 AFsp-v5r0 $";

#include <string.h>

#include <libtsp.h>
#include <libtsp/AFheader.h>
#include <libtsp/AFpar.h>
#include <libtsp/AFmsg.h>
#include <libtsp/UTpar.h>


AFILE *
AFsetNHwrite (FILE *fp, int Dformat, int Swapb, long int Nchan, double Sfreq)

{
  AFILE *AFp;
  struct AF_write AFw;

/* Check the swap code */
  if (! (Swapb == DS_EB || Swapb == DS_EL ||
	 Swapb == DS_NATIVE || Swapb == DS_SWAP)) {
    UTwarn ("AFsetNHwrite - %s", AFM_NH_InvSwap);
    return NULL;
  }
 
/* Set the parameters for file access */
  AFw.Sfreq = Sfreq;
  AFw.Nchan = Nchan;
  AFw.DFormat.Swapb = Swapb;
  AFw.DFormat.Format = Dformat;
  AFw.DFormat.ScaleF = 1.0;
  AFw.Hinfo.Info = NULL;
  AFw.Hinfo.N = 0;
  AFw.Hinfo.Nmax = 0;
  
  AFp = AFsetWrite (fp, FT_NH, &AFw);

  return AFp;
}
