/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  char *UTuserName (void)

Purpose:
  Get the user name and host name

Description:
  This routine returns the user name and host name.  The returned string is of
  the form user@host, with the host or @user parts omitted if unavailable.

Parameters:
  <-  char UTuserName[]
      Pointer to a character string containing the user name.  This string is
      null terminated.  This is a pointer to an internal static storage area;
      each call to this routine overlays this storage.

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.31 $  $Date: 1999/06/12 21:06:20 $

-------------------------------------------------------------------------*/

static char rcsid[] = "$Id: UTuserName.c 1.31 1999/06/12 AFsp-v5r0 $";

#include <libtsp.h>
#include <libtsp/nucleus.h>

#if (SY_OS == SY_OS_WINDOWS)
#  define MAXHOSTNAMELEN	257
#elif SY_POSIX
#  include <sys/param.h>		/* MAXHOSTNAMELEN on many systems */
#  ifndef MAXHOSTNAMELEN
#    include <netdb.h>			/* For Sun Solaris */
#    ifndef MAXHOSTNAMELEN		/* Last resort */
#      define MAXHOSTNAMELEN	257
#    endif
#  endif
#else
#  define MAXHOSTNAMELEN	0
#endif

#define MAXLEN	MAXHOSTNAMELEN+16+1	/* 16 chars for the user part */


char *
UTuserName (void)

{
  int n;
  static char User[MAXLEN+1];

  n = STcopyMax (UTgetUser (), User, MAXLEN);
  User[n] = '@';
  STcopyMax (UTgetHost (), &User[n+1], MAXLEN-(n+1));
  if (User[n+1] == '\0')
    User[n] = '\0';

  return User;
}
